@@ -1,8 +1,8 @@
 """RCON client library."""
 
 from rcon.asyncio import rcon
+from rcon.client import Client
 from rcon.exceptions import RequestIdMismatch, WrongPassword
-from rcon.proto import Client
 
 
 __all__ = ['RequestIdMismatch', 'WrongPassword', 'Client', 'rcon']
