@@ -4,19 +4,10 @@ from __future__ import annotations
 from enum import Enum
 from logging import getLogger
 from random import randint
-from socket import SOCK_STREAM, socket
-from typing import IO, NamedTuple, Optional
-
-from rcon.exceptions import RequestIdMismatch, WrongPassword
+from typing import IO, NamedTuple
 
 
-__all__ = [
-    'LittleEndianSignedInt32',
-    'Type',
-    'Packet',
-    'Client',
-    'random_request_id'
-]
+__all__ = ['LittleEndianSignedInt32', 'Type', 'Packet', 'random_request_id']
 
 
 LOGGER = getLogger(__file__)
@@ -139,79 +130,3 @@ class Packet(NamedTuple):
     def make_login(cls, passwd: str) -> Packet:
         """Creates a login packet."""
         return cls(random_request_id(), Type.SERVERDATA_AUTH, passwd)
-
-
-class Client:
-    """An RCON client."""
-
-    __slots__ = ('_socket', 'host', 'port', 'passwd')
-
-    def __init__(self, host: str, port: int, *,
-                 timeout: Optional[float] = None,
-                 passwd: Optional[str] = None):
-        """Initializes the base client with the SOCK_STREAM socket type."""
-        self._socket = socket(type=SOCK_STREAM)
-        self.host = host
-        self.port = port
-        self.timeout = timeout
-        self.passwd = passwd
-
-    def __enter__(self):
-        """Attempts an auto-login if a password is set."""
-        self._socket.__enter__()
-        self.connect(login=True)
-        return self
-
-    def __exit__(self, typ, value, traceback):
-        """Delegates to the underlying socket's exit method."""
-        return self._socket.__exit__(typ, value, traceback)
-
-    @property
-    def timeout(self) -> float:
-        """Returns the socket timeout."""
-        return self._socket.gettimeout()
-
-    @timeout.setter
-    def timeout(self, timeout: float):
-        """Sets the socket timeout."""
-        self._socket.settimeout(timeout)
-
-    def connect(self, login: bool = False) -> None:
-        """Connects the socket and attempts a
-        login if wanted and a password is set.
-        """
-        self._socket.connect((self.host, self.port))
-
-        if login and self.passwd is not None:
-            self.login(self.passwd)
-
-    def close(self) -> None:
-        """Closes the socket connection."""
-        self._socket.close()
-
-    def communicate(self, packet: Packet) -> Packet:
-        """Sends and receives a packet."""
-        with self._socket.makefile('wb') as file:
-            file.write(bytes(packet))
-
-        with self._socket.makefile('rb') as file:
-            return Packet.read(file)
-
-    def login(self, passwd: str) -> bool:
-        """Performs a login."""
-        response = self.communicate(Packet.make_login(passwd))
-
-        if response.id == -1:
-            raise WrongPassword()
-
-        return True
-
-    def run(self, command: str, *arguments: str, raw: bool = False) -> str:
-        """Runs a command."""
-        request = Packet.make_command(command, *arguments)
-        response = self.communicate(request)
-
-        if response.id != request.id:
-            raise RequestIdMismatch(request.id, response.id)
-
-        return response if raw else response.payload
